==> dde-launchpad_0.8.5.tar.xz: BUILD/translations/dde-launchpad_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>AnalysisView</name>
    <message>
        <source>No search results</source>
        <translation type="obsolete">Нічого не знайдено</translation>
    </message>
</context>
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Відкрити</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Пришпилити нагорі</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Вилучити з вибраного</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Додати до вибраного</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Надіслати на стільницю</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Видалити з стільниці</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Видалити з док-панелі</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Надіслати на панель</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Додати до запуску</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Вилучити із запуску</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Використовувати проксі</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Видалити</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">Інтернет</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">Спілкування</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">Музика</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Відео</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">Графіка</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">Офіс</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Читання</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">Розробка</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">Система</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="32"/>
        <source>Power</source>
        <translation type="unfinished">Живлення</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="56"/>
        <source>Search</source>
        <translation type="unfinished">Пошук</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="35"/>
        <source>Frequently Used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Apps</source>
        <translation type="obsolete">Усі програми</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Пошук</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation type="unfinished">Інтернет</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation type="unfinished">Спілкування</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation type="unfinished">Музика</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation type="unfinished">Відео</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation type="unfinished">Графіка</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation type="unfinished">Офіс</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation type="unfinished">Читання</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation type="unfinished">Розробка</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation type="unfinished">Система</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="398"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="410"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="424"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation type="unfinished">Усі програми</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation type="unfinished">Нічого не знайдено</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="142"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="153"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="164"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="175"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="186"/>
        <source>Control Center</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Categories</source>
        <translation type="vanished">Категорії</translation>
    </message>
    <message>
        <source>Power</source>
        <translation type="vanished">Живлення</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Налаштування</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Пошук</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="vanished">Мої улюблені</translation>
    </message>
    <message>
        <source>Add your favorite apps here</source>
        <translation type="vanished">Сюди ви можете додати вибрані програми</translation>
    </message>
    <message>
        <source>All Apps</source>
        <translation type="vanished">Усі програми</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation type="vanished">Нічого не знайдено</translation>
    </message>
</context>
</TS>

==> dde-launchpad_1.0.8.tar.xz: BUILD/translations/dde-launchpad_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Відкрити</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation>Пришпилити нагорі</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation>Пересунути нагору</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation>Вилучити з вибраного</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation>Додати до вибраного</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Надіслати на стільницю</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Видалити з стільниці</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Видалити з док-панелі</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Надіслати на панель</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Додати до запуску</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Вилучити із запуску</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Використовувати проксі</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation>Вимкнути масштабування дисплею</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Видалити</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="32"/>
        <source>Power</source>
        <translation>Живлення</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="56"/>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="103"/>
        <source>Full-screen Mode</source>
        <translation>Повноекранний режим</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation>Встановити</translation>
    </message>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation>Вилучити</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="35"/>
        <source>Frequently Used</source>
        <translation>Часто використані</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="150"/>
        <source>Window Mode</source>
        <translation>Режим вікна</translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation>Показати засіб запуску (типово приховано)</translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation>Показати/Приховати засіб запуску</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation>Інтернет</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation>Спілкування</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation>Відео</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation>Графіка</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Game</source>
        <translation>Ігри</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation>Офіс</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation>Читання</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation>Розробка</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation>Інше</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="411"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation>Ви справді хочете вилучити %1?</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="423"/>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="437"/>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation>Нещодавно встановлені</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation>Усі програми</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="566"/>
        <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation>Нічого не знайдено</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation>Довільне упорядкування</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation>Упорядкування за категоріями</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation>Упорядкування за назвами</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation>Режим упорядковування</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="144"/>
        <source>Computer</source>
        <translation>Комп&apos;ютер</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="155"/>
        <source>Pictures</source>
        <translation>Зображення</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="166"/>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="177"/>
        <source>Desktop</source>
        <translation>Стільниця</translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="188"/>
        <source>Control Center</source>
        <translation>Центр керування</translation>
    </message>
</context>
</TS>
